@@ -1,7 +1,7 @@
 see.mnom.tck <- function () 
 {
 
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL
     suppressWarnings(rm(slider.env))
@@ -49,4 +49,5 @@ see.mnom.tck <- function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
+    on.exit(par(old.par))
 }
